@@ -17,6 +17,7 @@ type TransferSnapshot struct {
 	Size        int64     `json:"size"`
 	Bytes       int64     `json:"bytes"`
 	Checked     bool      `json:"checked"`
+	What        string    `json:"what"`
 	StartedAt   time.Time `json:"started_at"`
 	CompletedAt time.Time `json:"completed_at,omitempty"`
 	Error       error     `json:"-"`
@@ -184,11 +185,18 @@ func (tr *Transfer) Snapshot() TransferSnapshot {
 	if tr.acc != nil {
 		b, s = tr.acc.progress()
 	}
+
+	what := tr.what
+	if what == "" {
+		what = "transferring"
+	}
+
 	snapshot := TransferSnapshot{
 		Name:        tr.remote,
-		Checked:     tr.checking,
 		Size:        s,
 		Bytes:       b,
+		Checked:     tr.checking,
+		What:        what,
 		StartedAt:   tr.startedAt,
 		CompletedAt: tr.completedAt,
 		Error:       tr.err,
